@@ -22,10 +22,9 @@ async def get_nh(id: int = choose().nhentai):
     img = parser['image_urls']
     print(f'Total image: {len(img)}')
 
-    neat_dir = split_name(__file__) + " - " + title
+    neat_dir = title
 
-    ## remove all " or ' in neat_dir
-    neat_dir = re.sub(r'[\'"]', '', neat_dir)
+    ## hapus semua tanda baca di neat_dir
 
     if not os.path.exists(neat_dir):
         os.makedirs(neat_dir)
